# PyComcigan Forked (with Runtime Validate and refactoring)

[check this library that well-documented](https://github.com/hegelty/pycomcigan)\
This package's behavior is certainly different and not compatible with original.

